/*  Copyright (C) 2013 Ben Asselstine

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
*/
#ifndef LU_STYLES_H
#define LU_STYLES_H 1

#include "comment-style.h"

extern struct argp styles_argp;
struct lu_comment_style_t * get_default_commenting_style();
struct lu_comment_style_t * lu_lookup_comment_style (char *arg);
int lu_is_a_comment_style (char *arg);
char * lu_list_of_comment_styles();
struct lu_comment_style_t * auto_detect_style (char *filename);
struct lu_comment_style_t * lu_get_current_commenting_style();
void show_all_comment_style_options();
void list_all_comment_style_options();
#endif
